#!/usr/bin/env python
"""Monitor 1.6
 '$Revision: 1.1.1.4.4.1.4.1 $ $Date: 2005/05/27 05:17:50 $ kgm'
This dummy module is only provided for backward compatibility.
It does nothing. class Monitor is now part of Simulation
and SimulationXXX."""
__version__ ='1.6 June 2005'
pass   
